==> ViennaCL-1.6.1.tar.gz: ViennaCL-1.6.1/doc/html/search/all_71.js <==
var searchData=
[
  ['qr_2dmethod_2dcommon_2ehpp',['qr-method-common.hpp',['../qr-method-common_8hpp.html',1,'']]],
  ['qr_2dmethod_2ehpp',['qr-method.hpp',['../qr-method_8hpp.html',1,'']]],
  ['qr_2ecpp',['qr.cpp',['../tutorial_2qr_8cpp.html',1,'']]],
  ['qr_2ecpp',['qr.cpp',['../benchmarks_2qr_8cpp.html',1,'']]],
  ['qr_2ehpp',['qr.hpp',['../detail_2spai_2qr_8hpp.html',1,'']]],
  ['qr_2ehpp',['qr.hpp',['../qr_8hpp.html',1,'']]],
  ['qr_5fmethod',['qr_method',['../namespaceviennacl_1_1linalg_1_1detail.html#a4983f4960a80f96d1dc3ff5ff23a0ffa',1,'viennacl::linalg::detail']]],
  ['qr_5fmethod_2ecpp',['qr_method.cpp',['../examples_2tutorial_2qr__method_8cpp.html',1,'']]],
  ['qr_5fmethod_2ecpp',['qr_method.cpp',['../tests_2src_2qr__method_8cpp.html',1,'']]],
  ['qr_5fmethod_5ffunc_2ecpp',['qr_method_func.cpp',['../qr__method__func_8cpp.html',1,'']]],
  ['qr_5fmethod_5fnsm',['qr_method_nsm',['../namespaceviennacl_1_1linalg.html#abe64190e92ee58ad753947142204d0f9',1,'viennacl::linalg']]],
  ['qr_5fmethod_5fsym',['qr_method_sym',['../namespaceviennacl_1_1linalg.html#a51cbe06645207f9b3054e8725269cc71',1,'viennacl::linalg']]],
  ['qrblockcomposition',['QRBlockComposition',['../namespaceviennacl_1_1linalg_1_1detail_1_1spai.html#a453c8768ecde4b09adaff9e130d8f3ed',1,'viennacl::linalg::detail::spai']]],
  ['queue_5fproperties',['queue_properties',['../classviennacl_1_1ocl_1_1device.html#a97d9e24c5c361a615344d6cbb7811af4',1,'viennacl::ocl::device']]],
  ['queue_5fproperties_5fto_5fstring',['queue_properties_to_string',['../classviennacl_1_1ocl_1_1device.html#a629b4e093d4cdd7d14571e1be533c113',1,'viennacl::ocl::device']]]
];

==> ViennaCL-1.7.1.tar.gz: ViennaCL-1.7.1/doc/html/search/all_71.js <==
var searchData=
[
  ['qr_2dmethod_2dcommon_2ehpp',['qr-method-common.hpp',['../qr-method-common_8hpp.html',1,'']]],
  ['qr_2dmethod_2ehpp',['qr-method.hpp',['../qr-method_8hpp.html',1,'']]],
  ['qr_2ecpp',['qr.cpp',['../tutorial_2qr_8cpp.html',1,'']]],
  ['qr_2ecpp',['qr.cpp',['../benchmarks_2qr_8cpp.html',1,'']]],
  ['qr_2ehpp',['qr.hpp',['../qr_8hpp.html',1,'']]],
  ['qr_2ehpp',['qr.hpp',['../detail_2spai_2qr_8hpp.html',1,'']]],
  ['qr_5fmethod',['qr_method',['../namespaceviennacl_1_1linalg_1_1detail.html#a4983f4960a80f96d1dc3ff5ff23a0ffa',1,'viennacl::linalg::detail']]],
  ['qr_5fmethod_2ecpp',['qr_method.cpp',['../tests_2src_2qr__method_8cpp.html',1,'']]],
  ['qr_5fmethod_2ecpp',['qr_method.cpp',['../examples_2tutorial_2qr__method_8cpp.html',1,'']]],
  ['qr_5fmethod_5ffunc_2ecpp',['qr_method_func.cpp',['../qr__method__func_8cpp.html',1,'']]],
  ['qr_5fmethod_5fnsm',['qr_method_nsm',['../namespaceviennacl_1_1linalg.html#abe64190e92ee58ad753947142204d0f9',1,'viennacl::linalg']]],
  ['qr_5fmethod_5fsym',['qr_method_sym',['../namespaceviennacl_1_1linalg.html#a51cbe06645207f9b3054e8725269cc71',1,'viennacl::linalg::qr_method_sym(viennacl::matrix&lt; SCALARTYPE &gt; &amp;A, viennacl::matrix&lt; SCALARTYPE &gt; &amp;Q, std::vector&lt; SCALARTYPE &gt; &amp;D)'],['../namespaceviennacl_1_1linalg.html#aec312fb569dcc41351adb8aeacbea571',1,'viennacl::linalg::qr_method_sym(viennacl::matrix&lt; SCALARTYPE &gt; &amp;A, viennacl::matrix&lt; SCALARTYPE &gt; &amp;Q, viennacl::vector_base&lt; SCALARTYPE &gt; &amp;D)']]],
  ['qrblockcomposition',['QRBlockComposition',['../namespaceviennacl_1_1linalg_1_1detail_1_1spai.html#a453c8768ecde4b09adaff9e130d8f3ed',1,'viennacl::linalg::detail::spai']]],
  ['queue_5fnot_5ffound',['queue_not_found',['../classviennacl_1_1ocl_1_1queue__not__found.html#a59470634f347e3bda949857a479fbad3',1,'viennacl::ocl::queue_not_found']]],
  ['queue_5fnot_5ffound',['queue_not_found',['../classviennacl_1_1ocl_1_1queue__not__found.html',1,'viennacl::ocl']]],
  ['queue_5fproperties',['queue_properties',['../classviennacl_1_1ocl_1_1device.html#a97d9e24c5c361a615344d6cbb7811af4',1,'viennacl::ocl::device']]],
  ['queue_5fproperties_5fto_5fstring',['queue_properties_to_string',['../classviennacl_1_1ocl_1_1device.html#a629b4e093d4cdd7d14571e1be533c113',1,'viennacl::ocl::device']]]
];
